package db

import (
	"database/sql"
	"database/sql/driver"
	"encoding/json"
	"strconv"
	"time"
)

type NullTime struct {
	sql.NullTime
}

func (v NullTime) MarshalJSON() ([]byte, error) {
	if v.Valid {
		return json.Marshal(v.Time)
	} else {
		return json.Marshal(nil)
	}
}

func (v *NullTime) UnmarshalJSON(data []byte) error {
	var s *time.Time
	if err := json.Unmarshal(data, &s); err != nil {
		return err
	}
	if s != nil {
		v.Valid = true
		v.Time = *s
	} else {
		v.Valid = false
	}
	return nil
}

type NullInt64 sql.NullInt64

func (v *NullInt64) Scan(value interface{}) error {
	return (*sql.NullInt64)(v).Scan(value)
}

func (v NullInt64) Value() (driver.Value, error) {
	if !v.Valid {
		return nil, nil
	}
	return v.Int64, nil
}

func (v *NullInt64) UnmarshalJSON(bytes []byte) error {
	if string(bytes) == "null" {
		v.Valid = false
		return nil
	}
	err := json.Unmarshal(bytes, &v.Int64)
	if err == nil {
		v.Valid = true
	}
	return err
}

func (v NullInt64) MarshalJSON() ([]byte, error) {
	if v.Valid {
		return strconv.AppendInt(nil, v.Int64, 10), nil
	}
	return []byte("null"), nil
}
